pub struct BBox<C = f64, const D: usize = 2> {
pub min: Point<C, D>,
pub max: Point<C, D>,
}Expand description
Axis-aligned bounding box in D dimensions.
Fields
min: Point<C, D>max: Point<C, D>Implementations
Sourceimpl<C: CoordType, const D: usize> BBox<C, D>
impl<C: CoordType, const D: usize> BBox<C, D>
Sourcepub fn new(min: Point<C, D>, max: Point<C, D>) -> Self
pub fn new(min: Point<C, D>, max: Point<C, D>) -> Self
Construct a bounding box from min and max points.
Sourcepub fn contains_point(&self, point: &Point<C, D>) -> bool
pub fn contains_point(&self, point: &Point<C, D>) -> bool
Returns true iff point lies within this box on all D axes (inclusive).
Sourcepub fn intersects(&self, other: &BBox<C, D>) -> bool
pub fn intersects(&self, other: &BBox<C, D>) -> bool
Returns true iff this bounding box overlaps other on all D axes.